@@ -1,6 +1,6 @@
-VERSION = (0, 3, 0)
+VERSION = (0, 4, 0)
 __version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
-__description__ = 'Asynchronous websocket + pubsub based web framework using tornado, redis, zmq, sockjs'
+__description__ = 'Asynchronous Websocket + Pubsub based web framework built over Tornado, Redis, ZMQ, SockJS'
 __author__ = 'Abhinav Singh'
 __author_email__ = 'mailsforabhinav@gmail.com'
 __homepage__ = 'https://github.com/abhinavsingh/tord'
