@@ -11,8 +11,7 @@ import async_pubsub
 
 from tornado import ioloop, web, template
 from sockjs.tornado import SockJSConnection, SockJSRouter
-
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('tord')
 
 # settings
 class Settings(): pass
@@ -67,7 +66,7 @@ class WSJSONPkt(object):
     def __init__(self, ws, raw):
         self.ws = ws
         self.raw = raw
-        self.sid = self.ws.sid
+        self.channel_id = self.ws.channel_id
 
     def __getitem__(self, key):
         return self.msg[key]
@@ -90,7 +89,7 @@ class WSJSONPkt(object):
             self.ws.send(out)
         else:
             out['_async_'] = True
-            settings.pubsub['klass'].publish(self.sid, json.dumps(out))
+            settings.pubsub['klass'].publish(self.channel_id, json.dumps(out))
     
     def reply_async(self, handler, *args, **kwargs):
         self.ws = None
@@ -102,7 +101,8 @@ class WSJSONPkt(object):
         try:
             self.msg = json.loads(self.raw)
         except ValueError, e:
-            raise WSBadPkt(str(e))
+            logger.exception(e)
+            raise WSBadPkt()
     
     def validate(self):
         if '_path_' not in self:
@@ -123,7 +123,8 @@ class WSJSONPkt(object):
         try:
             func(self, *match.groups())
         except Exception, e:
-            raise WSRouteException(str(e))
+            logger.exception(e)
+            raise WSRouteException()
 
 class HTTPRequestHandler(web.RequestHandler):
     
@@ -152,9 +153,7 @@ class WebSocketHandler(SockJSConnection):
     def on_open(self, info):
         self.info = info
         self.parse_sid_tid_from_path()
-        
-        # TODO: session initializer klass can be defined via app settings
-        params = self.start_anonymous_session(self)
+        params = self.session_initializer(self)
         
         if len(params) == 3:
             self.sid, self.uid, self.ses = params
@@ -162,6 +161,17 @@ class WebSocketHandler(SockJSConnection):
         else:
             raise WSSessionInitializationFailed('session initializer returned params tuple/list of length %s, expected 3' % len(params))
     
+    @property
+    def session_initializer(self):
+        session_initializer = settings.options['ws']['session_initializer'] if 'session_initializer' in settings.options['ws'] else self.start_anonymous_session
+        if type(session_initializer) in (str, unicode):
+            session_initializer = import_path(session_initializer)
+        return session_initializer
+    
+    @property
+    def channel_id(self):
+        return 'tord:sid:%s:tid:%s' % (self.sid, self.tid)
+    
     def connect_pubsub(self):
         settings.pubsub['opts']['callback'] = self.pubsub_callback
         self.pubsub = settings.pubsub['klass'](**settings.pubsub['opts'])
@@ -169,11 +179,11 @@ class WebSocketHandler(SockJSConnection):
         self.connected = False
     
     @staticmethod
-    def start_anonymous_session(ws):
+    def start_anonymous_session(_ws):
         sid = uuid.uuid4().hex
-        user = 'guest.%s' % random.randint(111, 9999)
+        uid = 'guest%s' % random.randint(111, 9999)
         session = dict()
-        return sid, user, session
+        return sid, uid, session
     
     def parse_sid_tid_from_path(self):
         parts = self.info.path.split('/')[2].split('_')
@@ -218,25 +228,29 @@ class WebSocketHandler(SockJSConnection):
         if evtype == async_pubsub.constants.CALLBACK_TYPE_CONNECTED:
             logger.info('Connected to pubsub')
             self.connected = True
-            self.pubsub.subscribe(self.sid)
+            self.pubsub.subscribe(self.channel_id)
+        
         elif evtype == async_pubsub.constants.CALLBACK_TYPE_DISCONNECTED:
             logger.info('Disconnected from pubsub')
             self.connected = False
+        
         elif evtype == async_pubsub.constants.CALLBACK_TYPE_SUBSCRIBED:
             logger.info('Subscribed to channel %s' % args[0])
-            if args[0] == self.sid:
+            if args[0] == self.channel_id:
                 self.send({'sid':self.sid, 'tid':self.tid, 'uid':self.uid, '_path_':'on_channel_open'})
+        
         elif evtype == async_pubsub.constants.CALLBACK_TYPE_UNSUBSCRIBED:
             logger.info('Unsubscribed to channel %s' % args[0])
+        
         elif evtype == async_pubsub.constants.CALLBACK_TYPE_MESSAGE:
-            if args[0] == self.sid:
-                logging.debug('pubsub channel: %s rcvd: %s' % (args[0], args[1]))
+            if args[0] == self.channel_id:
+                logger.debug('pubsub channel: %s rcvd: %s' % (args[0], args[1]))
                 self.send(args[1])
             else:
-                logging.debug('Rcvd msg %s on unhandled channel id %s' % (args[1], args[0]))
+                logger.debug('Rcvd msg %s on unhandled channel id %s' % (args[1], args[0]))
     
     def send(self, msg):
-        logging.debug('websocket send: %s' % msg)
+        logger.debug('websocket send: %s' % msg)
         if type(msg) not in (str, unicode):
             msg = json.dumps(msg)
         super(WebSocketHandler, self).send(msg)
@@ -337,11 +351,11 @@ class Application(object):
             debug=self.debug
         )
         self.app.listen(self.port)
-        print 'Listening on port %s ...' % self.port
+        logger.info('Listening on port %s ...' % self.port)
         
         try:
             ioloop.IOLoop.instance().start()
         except KeyboardInterrupt:
             pass
         finally:
-            print 'Shutting down ...'
+            logger.info('Shutting down ...')
